@@ -14,13 +14,14 @@ only use the `star' class for more granular control of the peakbagging process.
 
 """
 
-import os
+import os, warnings
 from .asy_peakbag import asymptotic_fit
 from .priors import kde
 from .peakbag import peakbag
 from .jar import get_priorpath, to_log10
 from .plotting import plotting
 import pandas as pd
+import numpy as np
 
 class star(plotting):
     """ Class for each star to be peakbagged
@@ -76,14 +77,18 @@ class star(plotting):
 
     """
 
-    def __init__(self, ID, pg, numax, dnu, teff, bp_rp, path=None,
-                 prior_file=None):
+    def __init__(self, ID, pg, numax, dnu, teff=[None,None], bp_rp=[None,None], 
+                 path=None, prior_file=None):
 
         self.ID = ID
         self.pg = pg.flatten()  # in case user supplies unormalized spectrum
 
+        if numax[0] < 25:
+            warnings.warn('The input numax is less than 25. The prior is not well defined here, so be careful with the result.')
         self.numax = numax
         self.dnu = dnu
+
+        teff, bp_rp = self._checkTeffBpRp(teff, bp_rp)
         self.teff = teff
         self.bp_rp = bp_rp
 
@@ -102,6 +107,22 @@ class star(plotting):
         else:
             self.prior_file = prior_file
 
+    def _checkTeffBpRp(self, teff, bp_rp):
+        # Teff and Gbp-Grp provide a lot of the same information, so only one of
+        # them need to be provided to start with. If one is not provided, PBjam
+        # will assume a wide prior on it.
+        teff_bad = np.all(np.array(teff) == [None,None]) or np.isnan(teff[0])
+        bp_rp_bad = np.all(np.array(bp_rp) == [None,None]) or np.isnan(bp_rp[0])
+        
+        if teff_bad and bp_rp_bad:
+            raise ValueError('Must provide either teff or bp_rp arguments when initializing the star class.')
+        elif teff_bad :
+            teff = [4889, 1500] # these are rough esimates from the prior
+        elif bp_rp_bad:
+            bp_rp = [1.2927, 0.5] # these are rough esimates from the prior
+
+        return teff, bp_rp
+
     def _outpath(self, x):
         """ Shorthand for setting the full output path
 
@@ -187,7 +208,8 @@ class star(plotting):
                                   savefig=make_plots)
 
     def run_asy_peakbag(self, norders, make_plots=False,
-                        store_chains=False):
+                        store_chains=False, method='mcmc', 
+                        developer_mode=False):
         """ Run all steps involving asy_peakbag.
 
         Performs a fit of the asymptotic relation to the spectrum (l=2,0 only),
@@ -201,7 +223,16 @@ class star(plotting):
             Whether or not to produce plots of the results. Default is False.
         store_chains : bool, optional
             Whether or not to store MCMC chains on disk. Default is False.
-
+        method : string
+            Method to be used for sampling the posterior. Options are 'mcmc' or
+            'nested. Default method is 'mcmc' that will call emcee, alternative
+            is 'nested' to call nested sampling with CPnest.
+        developer_mode : bool
+            Run asy_peakbag in developer mode. Currently just retains the input 
+            value of dnu and numax as priors, for the purposes of expanding
+            the prior sample. Important: This is not good practice for getting 
+            science results!
+            
         """
 
         print('Starting asymptotic peakbagging')
@@ -209,7 +240,7 @@ class star(plotting):
         asymptotic_fit(self, norders=norders)
 
         # Call
-        self.asy_fit()
+        self.asy_fit(method, developer_mode)
 
         # Store
         self.asy_fit.summary.to_csv(self._outpath(f'asymptotic_fit_summary_{self.ID}.csv'),
@@ -271,7 +302,8 @@ class star(plotting):
 
 
     def __call__(self, bw_fac=1.0, norders=8, model_type='simple', tune=1500,
-                 nthreads=1, make_plots=True, store_chains=True):
+                 nthreads=1, make_plots=True, store_chains=True, 
+                 asy_sampling='mcmc', developer_mode=False):
         """ Perform all the PBjam steps
 
         Starts by running KDE, followed by Asy_peakbag and then finally peakbag.
@@ -295,13 +327,22 @@ class star(plotting):
             Whether or not to produce plots of the results. Default is False.
         store_chains : bool, optional.
             Whether or not to store MCMC chains on disk. Default is False.
-            
+        asy_sampling : string
+            Method to be used for sampling the posterior in asy_peakbag. Options
+            are 'mcmc' or 'nested. Default method is 'mcmc' that will call 
+            emcee, alternative is 'nested' to call nested sampling with CPnest.
+        developer_mode : bool
+            Run asy_peakbag in developer mode. Currently just retains the input 
+            value of dnu and numax as priors, for the purposes of expanding
+            the prior sample. Important: This is not good practice for getting 
+            science results!    
         """
 
         self.run_kde(bw_fac=bw_fac, make_plots=make_plots)
 
         self.run_asy_peakbag(norders=norders, make_plots=make_plots,
-                             store_chains=store_chains)
+                             store_chains=store_chains, method=asy_sampling,
+                             developer_mode=developer_mode)
 
         self.run_peakbag(model_type=model_type, tune=tune, nthreads=nthreads,
                          make_plots=make_plots, store_chains=store_chains)
